==> gofigure2_0.8.1.orig.tar.gz: GoFigure2-v0.8.1/Code/IO/vtkPolyDataMySQLTrackReader.h <==
/*=========================================================================
 Authors: The GoFigure Dev. Team.
 at Megason Lab, Systems biology, Harvard Medical school, 2009-11

 Copyright (c) 2009-11, President and Fellows of Harvard College.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 Redistributions of source code must retain the above copyright notice,
 this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
 Neither the name of the  President and Fellows of Harvard College
 nor the names of its contributors may be used to endorse or promote
 products derived from this software without specific prior written
 permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef __vtkPolyDataMySQLTrackReader_h
#define __vtkPolyDataMySQLTrackReader_h

#include "vtkSmartPointer.h"
#include "vtkObject.h"

#include <map>
#include <string>

#include "QGoIOConfigure.h"

class vtkPolyData;

/**
\defgroup MySQLReader MySQLReader
\defgroup Track Track
\defgroup Trace Trace
*/

/**
\class vtkPolyDataMySQLTrackReader
\brief Reads a string and convert it into a track polydata
\ingroup MySQLReader Track Trace
*/

class QGOIO_EXPORT vtkPolyDataMySQLTrackReader:public vtkObject
{
public:
  /*
   * \brief Public constructor
   */
  static vtkPolyDataMySQLTrackReader * New();

  vtkTypeRevisionMacro(vtkPolyDataMySQLTrackReader, vtkObject);

  /*
   * \brief Generate a "Track Polydata" from a string
   * \param[in] iString base string to generate the polydata
   * \return pointer to the generated "Track Polydata"
   */
  vtkSmartPointer<vtkPolyData> GetPolyData(const std::string & iString);

  /*
   * \brief Generate a "Track Polydata" from a string
   * \param[in] iString base string to generate the polydata
   * \return pointer to the generated "Track Polydata"
   */
  std::map< unsigned int, double* > GetMap(const std::string & iString);

protected:
  vtkPolyDataMySQLTrackReader();
  ~vtkPolyDataMySQLTrackReader();

private:
  vtkPolyDataMySQLTrackReader(const vtkPolyDataMySQLTrackReader &);
  void operator=(const vtkPolyDataMySQLTrackReader &);
};

#endif

==> gofigure2_0.9.0.orig.tar.gz: GoFigure2-v0.9.0/Code/IO/vtkPolyDataMySQLTrackReader.h <==
/*=========================================================================
 Authors: The GoFigure Dev. Team.
 at Megason Lab, Systems biology, Harvard Medical school, 2009-11

 Copyright (c) 2009-11, President and Fellows of Harvard College.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 Redistributions of source code must retain the above copyright notice,
 this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
 Neither the name of the  President and Fellows of Harvard College
 nor the names of its contributors may be used to endorse or promote
 products derived from this software without specific prior written
 permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef __vtkPolyDataMySQLTrackReader_h
#define __vtkPolyDataMySQLTrackReader_h

#include "vtkSmartPointer.h"
#include "vtkObject.h"

#include <map>
#include <string>

#include "QGoIOConfigure.h"

class vtkPolyData;

/**
\defgroup MySQLReader MySQLReader
\defgroup Track Track
\defgroup Trace Trace
*/

/**
\class vtkPolyDataMySQLTrackReader
\brief Reads a string and convert it into a track polydata
\ingroup MySQLReader Track Trace
*/

class QGOIO_EXPORT vtkPolyDataMySQLTrackReader:public vtkObject
{
public:
  /*
   * \brief Public constructor
   */
  static vtkPolyDataMySQLTrackReader * New();

  vtkTypeRevisionMacro(vtkPolyDataMySQLTrackReader, vtkObject);

  /*
   * \brief Generate a "Track Polydata" from a string
   * \param[in] iString base string to generate the polydata
   * \return pointer to the generated "Track Polydata"
   */
  vtkSmartPointer<vtkPolyData> GetPolyData(const std::string & iString);

  /*
   * \brief Generate a "Track Polydata" from a string
   * \param[in] iString base string to generate the polydata
   * \return pointer to the generated "Track Polydata"
   */
  std::map< unsigned int, double* > GetMap(const std::string & iString);

protected:
  vtkPolyDataMySQLTrackReader();
  virtual ~vtkPolyDataMySQLTrackReader();

private:
  vtkPolyDataMySQLTrackReader(const vtkPolyDataMySQLTrackReader &);
  void operator=(const vtkPolyDataMySQLTrackReader &);
};

#endif
